@@ -1,7 +1,9 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012 Vincent Jacques
-# vincent@vincent-jacques.net
+# Copyright 2012 Steve English steve.english@navetas.com
+# Copyright 2012 Vincent Jacques vincent@vincent-jacques.net
+# Copyright 2012 Zearin zearin@gonk.net
+# Copyright 2013 Vincent Jacques vincent@vincent-jacques.net
 
 # This file is part of PyGithub. http://jacquev6.github.com/PyGithub/
 
@@ -198,12 +200,12 @@ class Gist(github.GithubObject.CompletableGithubObject):
         :rtype: None
         """
         assert description is github.GithubObject.NotSet or isinstance(description, (str, unicode)), description
-        assert files is github.GithubObject.NotSet or all(isinstance(element, github.InputFileContent) for element in files.itervalues()), files
+        assert files is github.GithubObject.NotSet or all(element is None or isinstance(element, github.InputFileContent) for element in files.itervalues()), files
         post_parameters = dict()
         if description is not github.GithubObject.NotSet:
             post_parameters["description"] = description
         if files is not github.GithubObject.NotSet:
-            post_parameters["files"] = dict((key, value._identity) for key, value in files.iteritems())
+            post_parameters["files"] = dict((key, None if value is None else value._identity) for key, value in files.iteritems())
         headers, data = self._requester.requestJsonAndCheck(
             "PATCH",
             self.url,
