@@ -8,6 +8,7 @@
 # Copyright 2012 Vincent Jacques vincent@vincent-jacques.net
 # Copyright 2012 Zearin zearin@gonk.net
 # Copyright 2013 Vincent Jacques vincent@vincent-jacques.net
+# Copyright 2013 Jonathan J Hunt hunt@braincorporation.com
 
 # This file is part of PyGithub. http://jacquev6.github.com/PyGithub/
 
@@ -145,7 +146,7 @@ class Requester:
             parameters = dict()
 
         requestHeaders = dict()
-        self.__authenticate(requestHeaders, parameters)
+        self.__authenticate(url, requestHeaders, parameters)
         requestHeaders["User-Agent"] = self.__userAgent
 
         url = self.__makeAbsoluteUrl(url)
@@ -185,8 +186,8 @@ class Requester:
 
         return status, responseHeaders, output
 
-    def __authenticate(self, requestHeaders, parameters):
-        if self.__clientId and self.__clientSecret:
+    def __authenticate(self, url, requestHeaders, parameters):
+        if self.__clientId and self.__clientSecret and "client_id=" not in url:
             parameters["client_id"] = self.__clientId
             parameters["client_secret"] = self.__clientSecret
         if self.__authorizationHeader is not None:
