@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012 Vincent Jacques
-# vincent@vincent-jacques.net
+# Copyright 2012 Vincent Jacques vincent@vincent-jacques.net
+# Copyright 2012 Zearin zearin@gonk.net
+# Copyright 2013 Vincent Jacques vincent@vincent-jacques.net
 
 # This file is part of PyGithub. http://jacquev6.github.com/PyGithub/
 
@@ -24,13 +25,13 @@ All classes inherit from :class:`github.GithubObject.GithubObject`.
 import logging
 
 from MainClass import Github
-from GithubException import GithubException
+from GithubException import GithubException, BadCredentialsException, UnknownObjectException
 from InputFileContent import InputFileContent
 from InputGitAuthor import InputGitAuthor
 from InputGitTreeElement import InputGitTreeElement
 
 
-def enable_console_debug_logging():  # pragma no cover
+def enable_console_debug_logging():  # pragma no cover (Function useful only outside test environment)
     """
     This function sets up a very simple logging configuration (log everything on standard output) that is useful for troubleshooting.
     """
