@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012 Vincent Jacques
-# vincent@vincent-jacques.net
+# Copyright 2012 Vincent Jacques vincent@vincent-jacques.net
+# Copyright 2012 Zearin zearin@gonk.net
+# Copyright 2013 Vincent Jacques vincent@vincent-jacques.net
 
 # This file is part of PyGithub. http://jacquev6.github.com/PyGithub/
 
@@ -28,6 +29,14 @@ class Enterprise(Framework.BasicTestCase):
         g = github.Github(self.login, self.password, base_url="http://my.enterprise.com")
         self.assertListKeyEqual(g.get_user().get_repos(), lambda r: r.name, ["TestPyGithub", "django", "PyGithub", "developer.github.com", "acme-public-website", "C4Planner", "Hacking", "vincent-jacques.net", "Contests", "Candidates", "Tests", "DrawTurksHead", "DrawSyntax", "QuadProgMm", "Boost.HierarchicalEnum", "ViDE"])
 
+    def testUnknownUrlScheme(self):  # To stay compatible with Python 2.6, we do not use self.assertRaises with only one argument
+        try:
+            github.Github(self.login, self.password, base_url="foobar://my.enterprise.com")
+        except AssertionError, exception:
+            raised = True
+            self.assertEqual(exception.args[0], "Unknown URL scheme")
+        self.assertTrue(raised)
+
     def testLongUrl(self):
         g = github.Github(self.login, self.password, base_url="http://my.enterprise.com/path/to/github")
         repos = g.get_user().get_repos()
