@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012 Vincent Jacques
-# vincent@vincent-jacques.net
+# Copyright 2012 Vincent Jacques vincent@vincent-jacques.net
+# Copyright 2012 Zearin zearin@gonk.net
+# Copyright 2013 Vincent Jacques vincent@vincent-jacques.net
 
 # This file is part of PyGithub. http://jacquev6.github.com/PyGithub/
 
@@ -57,7 +58,7 @@ class Exceptions(Framework.TestCase):  # To stay compatible with Python 2.6, we
             if atLeastPython26 and atMostPython2:
                 self.assertEqual(str(exception), "404 {u'message': u'Not Found'}")
             else:
-                self.assertEqual(str(exception), "404 {'message': 'Not Found'}")  # pragma no cover
+                self.assertEqual(str(exception), "404 {'message': 'Not Found'}")  # pragma no cover (Covered with Python 3)
         self.assertTrue(raised)
 
     def testUnknownUser(self):
@@ -71,7 +72,7 @@ class Exceptions(Framework.TestCase):  # To stay compatible with Python 2.6, we
             if atLeastPython26 and atMostPython2:
                 self.assertEqual(str(exception), "404 {u'message': u'Not Found'}")
             else:
-                self.assertEqual(str(exception), "404 {'message': 'Not Found'}")  # pragma no cover
+                self.assertEqual(str(exception), "404 {'message': 'Not Found'}")  # pragma no cover (Covered with Python 3)
         self.assertTrue(raised)
 
     def testBadAuthentication(self):
@@ -85,5 +86,13 @@ class Exceptions(Framework.TestCase):  # To stay compatible with Python 2.6, we
             if atLeastPython26 and atMostPython2:
                 self.assertEqual(str(exception), "401 {u'message': u'Bad credentials'}")
             else:
-                self.assertEqual(str(exception), "401 {'message': 'Bad credentials'}")  # pragma no cover
+                self.assertEqual(str(exception), "401 {'message': 'Bad credentials'}")  # pragma no cover (Covered with Python 3)
         self.assertTrue(raised)
+
+
+class SpecificExceptions(Framework.TestCase):
+    def testBadCredentials(self):
+        self.assertRaises(github.BadCredentialsException, lambda: github.Github("BadUser", "BadPassword").get_user().login)
+
+    def testUnknownObject(self):
+        self.assertRaises(github.UnknownObjectException, lambda: self.g.get_user().get_repo("Xxx"))
