@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012 Vincent Jacques
-# vincent@vincent-jacques.net
+# Copyright 2012 Vincent Jacques vincent@vincent-jacques.net
+# Copyright 2012 Zearin zearin@gonk.net
+# Copyright 2013 Vincent Jacques vincent@vincent-jacques.net
 
 # This file is part of PyGithub. http://jacquev6.github.com/PyGithub/
 
@@ -27,8 +28,8 @@ atMostPython32 = sys.hexversion < 0x03030000
 
 if atLeastPython26:
     import json
-else:  # pragma no cover
-    import simplejson as json  # pragma no cover
+else:  # pragma no cover (Covered by all tests with Python 2.5)
+    import simplejson as json  # pragma no cover (Covered by all tests with Python 2.5)
 
 
 def readLine(file):
@@ -53,15 +54,19 @@ class FakeHttpResponse:
 
 def fixAuthorizationHeader(headers):
     if "Authorization" in headers:
-        if headers["Authorization"].startswith("token "):
+        if headers["Authorization"].endswith("ZmFrZV9sb2dpbjpmYWtlX3Bhc3N3b3Jk"):
+            # This special case is here to test the real Authorization header
+            # sent by PyGithub. It would have avoided issue https://github.com/jacquev6/PyGithub/issues/153
+            # because we would have seen that Python 3 was not generating the same
+            # header as Python 2
+            pass
+        elif headers["Authorization"].startswith("token "):
             headers["Authorization"] = "token private_token_removed"
         elif headers["Authorization"].startswith("Basic "):
             headers["Authorization"] = "Basic login_and_password_removed"
-        else:  # pragma no cover
-            assert False
 
 
-class RecordingConnection:  # pragma no cover
+class RecordingConnection:  # pragma no cover (Class useful only when recording new tests, not used during automated tests)
     def __init__(self, file, protocol, host, port, *args, **kwds):
         self.__file = file
         self.__protocol = protocol
@@ -103,14 +108,14 @@ class RecordingConnection:  # pragma no cover
         self.__file.write(line + "\n")
 
 
-class RecordingHttpConnection(RecordingConnection):  # pragma no cover
+class RecordingHttpConnection(RecordingConnection):  # pragma no cover (Class useful only when recording new tests, not used during automated tests)
     _realConnection = httplib.HTTPConnection
 
     def __init__(self, file, *args, **kwds):
         RecordingConnection.__init__(self, file, "http", *args, **kwds)
 
 
-class RecordingHttpsConnection(RecordingConnection):  # pragma no cover
+class RecordingHttpsConnection(RecordingConnection):  # pragma no cover (Class useful only when recording new tests, not used during automated tests)
     _realConnection = httplib.HTTPSConnection
 
     def __init__(self, file, *args, **kwds):
@@ -175,7 +180,7 @@ class BasicTestCase(unittest.TestCase):
         unittest.TestCase.setUp(self)
         self.__fileName = ""
         self.__file = None
-        if self.recordMode:  # pragma no cover
+        if self.recordMode:  # pragma no cover (Branch useful only when recording new tests, not used during automated tests)
             github.Requester.Requester.injectConnectionClasses(
                 lambda ignored, *args, **kwds: RecordingHttpConnection(self.__openFile("wb"), *args, **kwds),
                 lambda ignored, *args, **kwds: RecordingHttpsConnection(self.__openFile("wb"), *args, **kwds)
@@ -216,7 +221,7 @@ class BasicTestCase(unittest.TestCase):
 
     def __closeReplayFileIfNeeded(self):
         if self.__file is not None:
-            if not self.recordMode:  # pragma no branch
+            if not self.recordMode:  # pragma no branch (Branch useful only when recording new tests, not used during automated tests)
                 self.assertEqual(readLine(self.__file), "")
             self.__file.close()
 
@@ -235,5 +240,5 @@ class TestCase(BasicTestCase):
         self.g = github.Github(self.login, self.password)
 
 
-def activateRecordMode():  # pragma no cover
+def activateRecordMode():  # pragma no cover (Function useful only when recording new tests, not used during automated tests)
     BasicTestCase.recordMode = True
